@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -295,6 +295,7 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                         continue;
                     } else if (2 == state) {
                         if (c == ' ') { // Comment line: "-- " + <rest-of-line>
+                            searchcontext = false;
                             final String readLine = in.readLine();
                             final Matcher dbmatcher = database.matcher(readLine);
                             final Matcher tablematcher = table.matcher(readLine);
@@ -402,7 +403,8 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
                                 // searchdbpool = false;
                                 // System.out.println(Arrays.toString(value));
                             } else {
-                                throw new OXContextRestoreException(Code.CONTEXT_NOT_FOUND_IN_POOL_MAPPING);
+                                state=5;
+                                continue;
                             }
                         } else if (null != bufferedWriter) {
                             // Here we should only search if a fitting db was found and thus the writer was set
@@ -730,7 +732,12 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
             LOG.error("", e);
             throw e;
         }
-
+        
+        final OXToolStorageInterface storage = OXToolStorageInterface.getInstance();
+        if (storage.isLastContextInSchema(ctx)) {
+            throw new OXContextRestoreException(Code.LAST_CONTEXT_IN_SCHEMA, ctx.getIdAsString());
+        }
+        
         LOG.info("Context: {}", ctx);
         LOG.info("Filenames: {}", java.util.Arrays.toString(fileNames));
 
@@ -762,7 +769,6 @@ public class OXContextRestore extends OXCommonImpl implements OXContextRestoreIn
 
             final OXContextInterface contextInterface = Activator.getContextInterface();
 
-            final OXToolStorageInterface storage = OXToolStorageInterface.getInstance();
             // We have to do the exists check beforehand otherwise you'll find a stack trace in the logs
             if (storage.existsContext(ctx)) {
                 try {
